@@ -1,10 +1,12 @@
-from typing import Any, Callable, Dict, List, Optional, Sequence, Union
+from collections.abc import Sequence
+from typing import Annotated, Any, Callable, Optional, Union
 
 from annotated_doc import Doc
 from fastapi import params
 from fastapi._compat import Undefined
 from fastapi.openapi.models import Example
-from typing_extensions import Annotated, Literal, deprecated
+from pydantic import AliasChoices, AliasPath
+from typing_extensions import Literal, deprecated
 
 _Unset: Any = Undefined
 
@@ -53,10 +55,8 @@ def Path(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -79,6 +79,9 @@ def Path(  # noqa: N802
         Doc(
             """
             Human-readable title.
+
+            Read more about it in the
+            [FastAPI docs for Path Parameters and Numeric Validations](https://fastapi.tiangolo.com/tutorial/path-params-numeric-validations/#declare-metadata)
             """
         ),
     ] = None,
@@ -96,6 +99,9 @@ def Path(  # noqa: N802
             """
             Greater than. If set, value must be greater than this. Only applicable to
             numbers.
+
+            Read more about it in the
+            [FastAPI docs about Path parameters numeric validations](https://fastapi.tiangolo.com/tutorial/path-params-numeric-validations/#number-validations-greater-than-and-less-than-or-equal)
             """
         ),
     ] = None,
@@ -105,6 +111,9 @@ def Path(  # noqa: N802
             """
             Greater than or equal. If set, value must be greater than or equal to
             this. Only applicable to numbers.
+
+            Read more about it in the
+            [FastAPI docs about Path parameters numeric validations](https://fastapi.tiangolo.com/tutorial/path-params-numeric-validations/#number-validations-greater-than-and-less-than-or-equal)
             """
         ),
     ] = None,
@@ -113,6 +122,9 @@ def Path(  # noqa: N802
         Doc(
             """
             Less than. If set, value must be less than this. Only applicable to numbers.
+
+            Read more about it in the
+            [FastAPI docs about Path parameters numeric validations](https://fastapi.tiangolo.com/tutorial/path-params-numeric-validations/#number-validations-greater-than-and-less-than-or-equal)
             """
         ),
     ] = None,
@@ -122,6 +134,9 @@ def Path(  # noqa: N802
             """
             Less than or equal. If set, value must be less than or equal to this.
             Only applicable to numbers.
+
+            Read more about it in the
+            [FastAPI docs about Path parameters numeric validations](https://fastapi.tiangolo.com/tutorial/path-params-numeric-validations/#number-validations-greater-than-and-less-than-or-equal)
             """
         ),
     ] = None,
@@ -209,10 +224,13 @@ def Path(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
+
+            Read more about it in the
+            [FastAPI docs for Declare Request Example Data](https://fastapi.tiangolo.com/tutorial/schema-extra-example/)
             """
         ),
     ] = None,
@@ -224,7 +242,7 @@ def Path(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -262,7 +280,7 @@ def Path(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -343,6 +361,9 @@ def Query(  # noqa: N802
         Doc(
             """
             Default value if the parameter field is not set.
+
+            Read more about it in the
+            [FastAPI docs about Query parameters](https://fastapi.tiangolo.com/tutorial/query-params-str-validations/#alternative-old-query-as-the-default-value)
             """
         ),
     ] = Undefined,
@@ -367,6 +388,9 @@ def Query(  # noqa: N802
             This will be used to extract the data and for the generated OpenAPI.
             It is particularly useful when you can't use the name you want because it
             is a Python reserved keyword or similar.
+
+            Read more about it in the
+            [FastAPI docs about Query parameters](https://fastapi.tiangolo.com/tutorial/query-params-str-validations/#alias-parameters)
             """
         ),
     ] = None,
@@ -378,10 +402,8 @@ def Query(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -404,6 +426,9 @@ def Query(  # noqa: N802
         Doc(
             """
             Human-readable title.
+
+            Read more about it in the
+            [FastAPI docs about Query parameters](https://fastapi.tiangolo.com/tutorial/query-params-str-validations/#declare-more-metadata)
             """
         ),
     ] = None,
@@ -412,6 +437,9 @@ def Query(  # noqa: N802
         Doc(
             """
             Human-readable description.
+
+            Read more about it in the
+            [FastAPI docs about Query parameters](https://fastapi.tiangolo.com/tutorial/query-params-str-validations/#declare-more-metadata)
             """
         ),
     ] = None,
@@ -421,6 +449,9 @@ def Query(  # noqa: N802
             """
             Greater than. If set, value must be greater than this. Only applicable to
             numbers.
+
+            Read more about it in the
+            [FastAPI docs about Path parameters numeric validations](https://fastapi.tiangolo.com/tutorial/path-params-numeric-validations/#number-validations-greater-than-and-less-than-or-equal)
             """
         ),
     ] = None,
@@ -430,6 +461,9 @@ def Query(  # noqa: N802
             """
             Greater than or equal. If set, value must be greater than or equal to
             this. Only applicable to numbers.
+
+            Read more about it in the
+            [FastAPI docs about Path parameters numeric validations](https://fastapi.tiangolo.com/tutorial/path-params-numeric-validations/#number-validations-greater-than-and-less-than-or-equal)
             """
         ),
     ] = None,
@@ -438,6 +472,9 @@ def Query(  # noqa: N802
         Doc(
             """
             Less than. If set, value must be less than this. Only applicable to numbers.
+
+            Read more about it in the
+            [FastAPI docs about Path parameters numeric validations](https://fastapi.tiangolo.com/tutorial/path-params-numeric-validations/#number-validations-greater-than-and-less-than-or-equal)
             """
         ),
     ] = None,
@@ -447,6 +484,9 @@ def Query(  # noqa: N802
             """
             Less than or equal. If set, value must be less than or equal to this.
             Only applicable to numbers.
+
+            Read more about it in the
+            [FastAPI docs about Path parameters numeric validations](https://fastapi.tiangolo.com/tutorial/path-params-numeric-validations/#number-validations-greater-than-and-less-than-or-equal)
             """
         ),
     ] = None,
@@ -455,6 +495,9 @@ def Query(  # noqa: N802
         Doc(
             """
             Minimum length for strings.
+
+            Read more about it in the
+            [FastAPI docs about Query parameters](https://fastapi.tiangolo.com/tutorial/query-params-str-validations/)
             """
         ),
     ] = None,
@@ -463,6 +506,9 @@ def Query(  # noqa: N802
         Doc(
             """
             Maximum length for strings.
+
+            Read more about it in the
+            [FastAPI docs about Query parameters](https://fastapi.tiangolo.com/tutorial/query-params-str-validations/)
             """
         ),
     ] = None,
@@ -471,6 +517,9 @@ def Query(  # noqa: N802
         Doc(
             """
             RegEx pattern for strings.
+
+            Read more about it in the
+            [FastAPI docs about Query parameters](https://fastapi.tiangolo.com/tutorial/query-params-str-validations/#add-regular-expressions
             """
         ),
     ] = None,
@@ -534,10 +583,13 @@ def Query(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
+
+            Read more about it in the
+            [FastAPI docs for Declare Request Example Data](https://fastapi.tiangolo.com/tutorial/schema-extra-example/)
             """
         ),
     ] = None,
@@ -549,7 +601,7 @@ def Query(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -572,6 +624,9 @@ def Query(  # noqa: N802
             Mark this parameter field as deprecated.
 
             It will affect the generated OpenAPI (e.g. visible at `/docs`).
+
+            Read more about it in the
+            [FastAPI docs about Query parameters](https://fastapi.tiangolo.com/tutorial/query-params-str-validations/#deprecating-parameters)
             """
         ),
     ] = None,
@@ -583,11 +638,14 @@ def Query(  # noqa: N802
             You probably don't need it, but it's available.
 
             This affects the generated OpenAPI (e.g. visible at `/docs`).
+
+            Read more about it in the
+            [FastAPI docs about Query parameters](https://fastapi.tiangolo.com/tutorial/query-params-str-validations/#exclude-parameters-from-openapi
             """
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -682,10 +740,8 @@ def Header(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -849,10 +905,13 @@ def Header(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
+
+            Read more about it in the
+            [FastAPI docs for Declare Request Example Data](https://fastapi.tiangolo.com/tutorial/schema-extra-example/)
             """
         ),
     ] = None,
@@ -864,7 +923,7 @@ def Header(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -902,7 +961,7 @@ def Header(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -998,10 +1057,8 @@ def Cookie(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -1154,10 +1211,13 @@ def Cookie(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
+
+            Read more about it in the
+            [FastAPI docs for Declare Request Example Data](https://fastapi.tiangolo.com/tutorial/schema-extra-example/)
             """
         ),
     ] = None,
@@ -1169,7 +1229,7 @@ def Cookie(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -1207,7 +1267,7 @@ def Cookie(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -1325,10 +1385,8 @@ def Body(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -1481,10 +1539,13 @@ def Body(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
+
+            Read more about it in the
+            [FastAPI docs for Declare Request Example Data](https://fastapi.tiangolo.com/tutorial/schema-extra-example/)
             """
         ),
     ] = None,
@@ -1496,7 +1557,7 @@ def Body(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -1534,7 +1595,7 @@ def Body(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -1640,10 +1701,8 @@ def Form(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -1796,10 +1855,13 @@ def Form(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
+
+            Read more about it in the
+            [FastAPI docs for Declare Request Example Data](https://fastapi.tiangolo.com/tutorial/schema-extra-example/)
             """
         ),
     ] = None,
@@ -1811,7 +1873,7 @@ def Form(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -1849,7 +1911,7 @@ def Form(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -1954,10 +2016,8 @@ def File(  # noqa: N802
             """
         ),
     ] = _Unset,
-    # TODO: update when deprecating Pydantic v1, import these types
-    # validation_alias: str | AliasPath | AliasChoices | None
     validation_alias: Annotated[
-        Union[str, None],
+        Union[str, AliasPath, AliasChoices, None],
         Doc(
             """
             'Whitelist' validation step. The parameter field will be the single one
@@ -2110,10 +2170,13 @@ def File(  # noqa: N802
         ),
     ] = _Unset,
     examples: Annotated[
-        Optional[List[Any]],
+        Optional[list[Any]],
         Doc(
             """
             Example values for this field.
+
+            Read more about it in the
+            [FastAPI docs for Declare Request Example Data](https://fastapi.tiangolo.com/tutorial/schema-extra-example/)
             """
         ),
     ] = None,
@@ -2125,7 +2188,7 @@ def File(  # noqa: N802
         ),
     ] = _Unset,
     openapi_examples: Annotated[
-        Optional[Dict[str, Example]],
+        Optional[dict[str, Example]],
         Doc(
             """
             OpenAPI-specific examples.
@@ -2163,7 +2226,7 @@ def File(  # noqa: N802
         ),
     ] = True,
     json_schema_extra: Annotated[
-        Union[Dict[str, Any], None],
+        Union[dict[str, Any], None],
         Doc(
             """
             Any additional JSON schema data.
@@ -2227,6 +2290,9 @@ def Depends(  # noqa: N802
 
             Don't call it directly, FastAPI will call it for you, just pass the object
             directly.
+
+            Read more about it in the
+            [FastAPI docs for Dependencies](https://fastapi.tiangolo.com/tutorial/dependencies/)
             """
         ),
     ] = None,
@@ -2242,6 +2308,9 @@ def Depends(  # noqa: N802
 
             Set `use_cache` to `False` to disable this behavior and ensure the
             dependency is called again (if declared more than once) in the same request.
+
+            Read more about it in the
+            [FastAPI docs about sub-dependencies](https://fastapi.tiangolo.com/tutorial/dependencies/sub-dependencies/#using-the-same-dependency-multiple-times)
             """
         ),
     ] = True,
@@ -2262,6 +2331,9 @@ def Depends(  # noqa: N802
                 that handles the request (similar to when using `"function"`), but end
                 **after** the response is sent back to the client. So, the dependency
                 function will be executed **around** the **request** and response cycle.
+
+            Read more about it in the
+            [FastAPI docs for FastAPI Dependencies with yield](https://fastapi.tiangolo.com/tutorial/dependencies/dependencies-with-yield/#early-exit-and-scope)
             """
         ),
     ] = None,
@@ -2307,6 +2379,9 @@ def Security(  # noqa: N802
 
             Don't call it directly, FastAPI will call it for you, just pass the object
             directly.
+
+            Read more about it in the
+            [FastAPI docs for Dependencies](https://fastapi.tiangolo.com/tutorial/dependencies/)
             """
         ),
     ] = None,
@@ -2324,7 +2399,9 @@ def Security(  # noqa: N802
 
             These scopes are integrated with OpenAPI (and the API docs at `/docs`).
             So they are visible in the OpenAPI specification.
-            )
+
+            Read more about it in the
+            [FastAPI docs about OAuth2 scopes](https://fastapi.tiangolo.com/advanced/security/oauth2-scopes/)
             """
         ),
     ] = None,
@@ -2339,6 +2416,9 @@ def Security(  # noqa: N802
 
             Set `use_cache` to `False` to disable this behavior and ensure the
             dependency is called again (if declared more than once) in the same request.
+
+            Read more about it in the
+            [FastAPI docs about sub-dependencies](https://fastapi.tiangolo.com/tutorial/dependencies/sub-dependencies/#using-the-same-dependency-multiple-times)
             """
         ),
     ] = True,
